@@ -18,10 +18,11 @@
 # limitations under the License.
 ################################################################################
 
+SCRIPT_PATH=$(cd `dirname $0`; pwd)
 # set up root directory
-WS_ROOT=`dirname $PWD`
+WS_ROOT=`dirname $SCRIPT_PATH`
 # shut down cluster
-HUDI_WS=${WS_ROOT} docker-compose -f compose/docker-compose_hadoop284_hive233_spark231.yml down
+HUDI_WS=${WS_ROOT} docker-compose -f ${SCRIPT_PATH}/compose/docker-compose_hadoop284_hive233_spark244.yml down
 
 # remove houst mount directory
 rm -rf /tmp/hadoop_data
