@@ -18,17 +18,10 @@
 
 package org.apache.hudi;
 
-import static org.apache.hudi.common.model.HoodieTableType.MERGE_ON_READ;
-
-import java.io.IOException;
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.stream.Collectors;
 import org.apache.hudi.CompactionAdminClient.ValidationOpResult;
 import org.apache.hudi.common.model.CompactionOperation;
+import org.apache.hudi.common.model.FileSlice;
+import org.apache.hudi.common.model.HoodieFileGroup;
 import org.apache.hudi.common.model.HoodieLogFile;
 import org.apache.hudi.common.model.HoodieTestUtils;
 import org.apache.hudi.common.table.HoodieTableMetaClient;
@@ -39,13 +32,31 @@ import org.apache.hudi.common.util.Option;
 import org.apache.hudi.common.util.collection.Pair;
 import org.apache.hudi.exception.HoodieException;
 import org.apache.hudi.exception.HoodieIOException;
+
+import org.apache.hudi.func.OperationResult;
+import org.apache.log4j.LogManager;
+import org.apache.log4j.Logger;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
+import java.io.IOException;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
+import static org.apache.hudi.CompactionAdminClient.getRenamingActionsToAlignWithCompactionOperation;
+import static org.apache.hudi.CompactionAdminClient.renameLogFile;
+import static org.apache.hudi.common.model.HoodieTableType.MERGE_ON_READ;
+
 public class TestCompactionAdminClient extends TestHoodieClientBase {
 
+  private static final Logger LOG = LogManager.getLogger(TestCompactionAdminClient.class);
+
   private HoodieTableMetaClient metaClient;
   private CompactionAdminClient client;
 
@@ -85,7 +96,7 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     CompactionTestUtils.setupAndValidateCompactionOperations(metaClient, false, numEntriesPerInstant,
         numEntriesPerInstant, numEntriesPerInstant, numEntriesPerInstant);
     Map<String, CompactionOperation> instantsWithOp =
-        Arrays.asList("001", "003", "005", "007").stream().map(instant -> {
+        Stream.of("001", "003", "005", "007").map(instant -> {
           try {
             return Pair.of(instant, CompactionUtils.getCompactionPlan(metaClient, instant));
           } catch (IOException ioe) {
@@ -126,14 +137,14 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     metaClient = new HoodieTableMetaClient(metaClient.getHadoopConf(), basePath, true);
     List<ValidationOpResult> result = client.validateCompactionPlan(metaClient, compactionInstant, 1);
     if (expNumRepairs > 0) {
-      Assert.assertTrue("Expect some failures in validation", result.stream().filter(r -> !r.isSuccess()).count() > 0);
+      Assert.assertTrue("Expect some failures in validation", result.stream().anyMatch(r -> !r.isSuccess()));
     }
     // Now repair
     List<Pair<HoodieLogFile, HoodieLogFile>> undoFiles =
-        result.stream().flatMap(r -> client.getRenamingActionsToAlignWithCompactionOperation(metaClient,
+        result.stream().flatMap(r -> getRenamingActionsToAlignWithCompactionOperation(metaClient,
             compactionInstant, r.getOperation(), Option.empty()).stream()).map(rn -> {
               try {
-                client.renameLogFile(metaClient, rn.getKey(), rn.getValue());
+                renameLogFile(metaClient, rn.getKey(), rn.getValue());
               } catch (IOException e) {
                 throw new HoodieIOException(e.getMessage(), e);
               }
@@ -148,20 +159,18 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     } else {
       Assert.assertTrue("Rename Files must be empty", renameFiles.isEmpty());
     }
-    expRenameFiles.entrySet().stream().forEach(r -> {
-      logger.info("Key :" + r.getKey() + " renamed to " + r.getValue() + " rolled back to "
-          + renameFilesFromUndo.get(r.getKey()));
-    });
+    expRenameFiles.forEach((key, value) -> LOG.info("Key :" + key + " renamed to " + value + " rolled back to "
+        + renameFilesFromUndo.get(key)));
 
     Assert.assertEquals("Undo must completely rollback renames", expRenameFiles, renameFilesFromUndo);
     // Now expect validation to succeed
     result = client.validateCompactionPlan(metaClient, compactionInstant, 1);
-    Assert.assertTrue("Expect no failures in validation", result.stream().filter(r -> !r.isSuccess()).count() == 0);
+    Assert.assertTrue("Expect no failures in validation", result.stream().allMatch(OperationResult::isSuccess));
     Assert.assertEquals("Expected Num Repairs", expNumRepairs, undoFiles.size());
   }
 
   /**
-   * Enssure compaction plan is valid
+   * Enssure compaction plan is valid.
    *
    * @param compactionInstant Compaction Instant
    */
@@ -170,7 +179,7 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     // Ensure compaction-plan is good to begin with
     List<ValidationOpResult> validationResults = client.validateCompactionPlan(metaClient, compactionInstant, 1);
     Assert.assertFalse("Some validations failed",
-        validationResults.stream().filter(v -> !v.isSuccess()).findAny().isPresent());
+        validationResults.stream().anyMatch(v -> !v.isSuccess()));
   }
 
   private void validateRenameFiles(List<Pair<HoodieLogFile, HoodieLogFile>> renameFiles, String ingestionInstant,
@@ -179,14 +188,14 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     Set<HoodieLogFile> uniqNewLogFiles = new HashSet<>();
     Set<HoodieLogFile> uniqOldLogFiles = new HashSet<>();
 
-    renameFiles.stream().forEach(lfPair -> {
+    renameFiles.forEach(lfPair -> {
       Assert.assertFalse("Old Log File Names do not collide", uniqOldLogFiles.contains(lfPair.getKey()));
       Assert.assertFalse("New Log File Names do not collide", uniqNewLogFiles.contains(lfPair.getValue()));
       uniqOldLogFiles.add(lfPair.getKey());
       uniqNewLogFiles.add(lfPair.getValue());
     });
 
-    renameFiles.stream().forEach(lfPair -> {
+    renameFiles.forEach(lfPair -> {
       HoodieLogFile oldLogFile = lfPair.getLeft();
       HoodieLogFile newLogFile = lfPair.getValue();
       Assert.assertEquals("Base Commit time is expected", ingestionInstant, newLogFile.getBaseCommitTime());
@@ -204,7 +213,7 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
   }
 
   /**
-   * Validate Unschedule operations
+   * Validate Unschedule operations.
    */
   private List<Pair<HoodieLogFile, HoodieLogFile>> validateUnSchedulePlan(CompactionAdminClient client,
       String ingestionInstant, String compactionInstant, int numEntriesPerInstant, int expNumRenames) throws Exception {
@@ -213,7 +222,7 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
   }
 
   /**
-   * Validate Unschedule operations
+   * Validate Unschedule operations.
    */
   private List<Pair<HoodieLogFile, HoodieLogFile>> validateUnSchedulePlan(CompactionAdminClient client,
       String ingestionInstant, String compactionInstant, int numEntriesPerInstant, int expNumRenames,
@@ -228,20 +237,20 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
 
     // Log files belonging to file-slices created because of compaction request must be renamed
 
-    Set<HoodieLogFile> gotLogFilesToBeRenamed = renameFiles.stream().map(p -> p.getLeft()).collect(Collectors.toSet());
+    Set<HoodieLogFile> gotLogFilesToBeRenamed = renameFiles.stream().map(Pair::getLeft).collect(Collectors.toSet());
     final HoodieTableFileSystemView fsView =
         new HoodieTableFileSystemView(metaClient, metaClient.getCommitsAndCompactionTimeline());
     Set<HoodieLogFile> expLogFilesToBeRenamed = fsView.getLatestFileSlices(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0])
-        .filter(fs -> fs.getBaseInstantTime().equals(compactionInstant)).flatMap(fs -> fs.getLogFiles())
+        .filter(fs -> fs.getBaseInstantTime().equals(compactionInstant)).flatMap(FileSlice::getLogFiles)
         .collect(Collectors.toSet());
     Assert.assertEquals("Log files belonging to file-slices created because of compaction request must be renamed",
         expLogFilesToBeRenamed, gotLogFilesToBeRenamed);
 
     if (skipUnSchedule) {
       // Do the renaming only but do not touch the compaction plan - Needed for repair tests
-      renameFiles.stream().forEach(lfPair -> {
+      renameFiles.forEach(lfPair -> {
         try {
-          client.renameLogFile(metaClient, lfPair.getLeft(), lfPair.getRight());
+          renameLogFile(metaClient, lfPair.getLeft(), lfPair.getRight());
         } catch (IOException e) {
           throw new HoodieIOException(e.getMessage(), e);
         }
@@ -266,13 +275,13 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     // Expect all file-slice whose base-commit is same as compaction commit to contain no new Log files
     newFsView.getLatestFileSlicesBeforeOrOn(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0], compactionInstant, true)
         .filter(fs -> fs.getBaseInstantTime().equals(compactionInstant)).forEach(fs -> {
-          Assert.assertFalse("No Data file must be present", fs.getDataFile().isPresent());
-          Assert.assertTrue("No Log Files", fs.getLogFiles().count() == 0);
+          Assert.assertFalse("No Data file must be present", fs.getBaseFile().isPresent());
+          Assert.assertEquals("No Log Files", 0, fs.getLogFiles().count());
         });
 
     // Ensure same number of log-files before and after renaming per fileId
     Map<String, Long> fileIdToCountsAfterRenaming =
-        newFsView.getAllFileGroups(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0]).flatMap(fg -> fg.getAllFileSlices())
+        newFsView.getAllFileGroups(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0]).flatMap(HoodieFileGroup::getAllFileSlices)
             .filter(fs -> fs.getBaseInstantTime().equals(ingestionInstant))
             .map(fs -> Pair.of(fs.getFileId(), fs.getLogFiles().count()))
             .collect(Collectors.toMap(Pair::getKey, Pair::getValue));
@@ -285,7 +294,7 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
   }
 
   /**
-   * Validate Unschedule operations
+   * Validate Unschedule operations.
    */
   private void validateUnScheduleFileId(CompactionAdminClient client, String ingestionInstant, String compactionInstant,
       CompactionOperation op, int expNumRenames) throws Exception {
@@ -299,12 +308,12 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
 
     // Log files belonging to file-slices created because of compaction request must be renamed
 
-    Set<HoodieLogFile> gotLogFilesToBeRenamed = renameFiles.stream().map(p -> p.getLeft()).collect(Collectors.toSet());
+    Set<HoodieLogFile> gotLogFilesToBeRenamed = renameFiles.stream().map(Pair::getLeft).collect(Collectors.toSet());
     final HoodieTableFileSystemView fsView =
         new HoodieTableFileSystemView(metaClient, metaClient.getCommitsAndCompactionTimeline());
     Set<HoodieLogFile> expLogFilesToBeRenamed = fsView.getLatestFileSlices(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0])
         .filter(fs -> fs.getBaseInstantTime().equals(compactionInstant))
-        .filter(fs -> fs.getFileId().equals(op.getFileId())).flatMap(fs -> fs.getLogFiles())
+        .filter(fs -> fs.getFileId().equals(op.getFileId())).flatMap(FileSlice::getLogFiles)
         .collect(Collectors.toSet());
     Assert.assertEquals("Log files belonging to file-slices created because of compaction request must be renamed",
         expLogFilesToBeRenamed, gotLogFilesToBeRenamed);
@@ -327,13 +336,13 @@ public class TestCompactionAdminClient extends TestHoodieClientBase {
     newFsView.getLatestFileSlicesBeforeOrOn(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0], compactionInstant, true)
         .filter(fs -> fs.getBaseInstantTime().equals(compactionInstant))
         .filter(fs -> fs.getFileId().equals(op.getFileId())).forEach(fs -> {
-          Assert.assertFalse("No Data file must be present", fs.getDataFile().isPresent());
-          Assert.assertTrue("No Log Files", fs.getLogFiles().count() == 0);
+          Assert.assertFalse("No Data file must be present", fs.getBaseFile().isPresent());
+          Assert.assertEquals("No Log Files", 0, fs.getLogFiles().count());
         });
 
     // Ensure same number of log-files before and after renaming per fileId
     Map<String, Long> fileIdToCountsAfterRenaming =
-        newFsView.getAllFileGroups(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0]).flatMap(fg -> fg.getAllFileSlices())
+        newFsView.getAllFileGroups(HoodieTestUtils.DEFAULT_PARTITION_PATHS[0]).flatMap(HoodieFileGroup::getAllFileSlices)
             .filter(fs -> fs.getBaseInstantTime().equals(ingestionInstant))
             .filter(fs -> fs.getFileId().equals(op.getFileId()))
             .map(fs -> Pair.of(fs.getFileId(), fs.getLogFiles().count()))
