@@ -18,20 +18,6 @@
 
 package org.apache.hudi.io;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
-import com.google.common.collect.Sets;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-import java.util.stream.Collectors;
-import org.apache.avro.generic.GenericRecord;
-import org.apache.avro.generic.IndexedRecord;
-import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.fs.Path;
 import org.apache.hudi.HoodieClientTestHarness;
 import org.apache.hudi.avro.model.HoodieArchivedMetaEntry;
 import org.apache.hudi.common.HoodieTestDataGenerator;
@@ -47,10 +33,26 @@ import org.apache.hudi.common.table.timeline.HoodieInstant;
 import org.apache.hudi.common.table.timeline.HoodieInstant.State;
 import org.apache.hudi.config.HoodieCompactionConfig;
 import org.apache.hudi.config.HoodieWriteConfig;
+
+import com.google.common.collect.Sets;
+import org.apache.avro.generic.GenericRecord;
+import org.apache.avro.generic.IndexedRecord;
+import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.fs.Path;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Set;
+import java.util.stream.Collectors;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+
 public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
 
   private Configuration hadoopConf;
@@ -74,7 +76,7 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
   }
 
   @Test
-  public void testArchiveEmptyDataset() throws IOException {
+  public void testArchiveEmptyTable() throws IOException {
     HoodieWriteConfig cfg =
         HoodieWriteConfig.newBuilder().withPath(basePath).withSchema(HoodieTestDataGenerator.TRIP_EXAMPLE_SCHEMA)
             .withParallelism(2, 2).forTable("test-trip-table").build();
@@ -85,7 +87,7 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
   }
 
   @Test
-  public void testArchiveDatasetWithArchival() throws IOException {
+  public void testArchiveTableWithArchival() throws IOException {
     HoodieWriteConfig cfg = HoodieWriteConfig.newBuilder().withPath(basePath)
         .withSchema(HoodieTestDataGenerator.TRIP_EXAMPLE_SCHEMA).withParallelism(2, 2)
         .withCompactionConfig(HoodieCompactionConfig.newBuilder().retainCommits(1).archiveCommitsWith(2, 4).build())
@@ -139,14 +141,13 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
 
     assertEquals("Loaded 6 commits and the count should match", 6, timeline.countInstants());
 
-    HoodieTestUtils.createCleanFiles(basePath, "100", dfs.getConf());
-    HoodieTestUtils.createInflightCleanFiles(basePath, dfs.getConf(), "101");
-    HoodieTestUtils.createCleanFiles(basePath, "101", dfs.getConf());
-    HoodieTestUtils.createCleanFiles(basePath, "102", dfs.getConf());
-    HoodieTestUtils.createCleanFiles(basePath, "103", dfs.getConf());
-    HoodieTestUtils.createCleanFiles(basePath, "104", dfs.getConf());
-    HoodieTestUtils.createCleanFiles(basePath, "105", dfs.getConf());
-    HoodieTestUtils.createInflightCleanFiles(basePath, dfs.getConf(), "106", "107");
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "100", dfs.getConf());
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "101", dfs.getConf());
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "102", dfs.getConf());
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "103", dfs.getConf());
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "104", dfs.getConf());
+    HoodieTestUtils.createCleanFiles(metaClient, basePath, "105", dfs.getConf());
+    HoodieTestUtils.createPendingCleanFiles(metaClient, "106", "107");
 
     // reload the timeline and get all the commmits before archive
     timeline = metaClient.getActiveTimeline().reload().getAllCommitsTimeline().filterCompletedInstants();
@@ -155,7 +156,7 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     assertEquals("Loaded 6 commits and the count should match", 12, timeline.countInstants());
 
     // verify in-flight instants before archive
-    verifyInflightInstants(metaClient, 3);
+    verifyInflightInstants(metaClient, 2);
 
     metaClient = HoodieTableMetaClient.reload(metaClient);
     HoodieCommitArchiveLog archiveLog = new HoodieCommitArchiveLog(cfg, metaClient);
@@ -167,8 +168,8 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     originalCommits.removeAll(timeline.getInstants().collect(Collectors.toList()));
 
     // Check compaction instants
-    List<HoodieInstant> instants = HoodieTableMetaClient.scanHoodieInstantsFromFileSystem(metaClient.getFs(),
-        new Path(metaClient.getMetaAuxiliaryPath()), HoodieActiveTimeline.VALID_EXTENSIONS_IN_ACTIVE_TIMELINE);
+    List<HoodieInstant> instants = metaClient.scanHoodieInstantsFromFileSystem(
+        new Path(metaClient.getMetaAuxiliaryPath()), HoodieActiveTimeline.VALID_EXTENSIONS_IN_ACTIVE_TIMELINE, false);
     assertEquals("Should delete all compaction instants < 104", 4, instants.size());
     assertFalse("Requested Compaction must be absent for 100",
         instants.contains(new HoodieInstant(State.REQUESTED, HoodieTimeline.COMPACTION_ACTION, "100")));
@@ -199,35 +200,36 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     Reader reader =
         HoodieLogFormat.newReader(dfs, new HoodieLogFile(new Path(basePath + "/.hoodie/.commits_.archive.1_1-0-1")),
             HoodieArchivedMetaEntry.getClassSchema());
-
     int archivedRecordsCount = 0;
     List<IndexedRecord> readRecords = new ArrayList<>();
     // read the avro blocks and validate the number of records written in each avro block
+    int numBlocks = 0;
     while (reader.hasNext()) {
       HoodieAvroDataBlock blk = (HoodieAvroDataBlock) reader.next();
       List<IndexedRecord> records = blk.getRecords();
       readRecords.addAll(records);
-      assertEquals("Archived and read records for each block are same", 8, records.size());
       archivedRecordsCount += records.size();
+      numBlocks++;
     }
-    assertEquals("Total archived records and total read records are the same count", 8, archivedRecordsCount);
-
+    System.out.println("Read Records :" + readRecords.stream().map(r -> (GenericRecord) r)
+        .map(r -> r.get("actionType") + "_" + r.get("actionState") + "_" + r.get("commitTime")).collect(Collectors.toList()));
+    assertEquals("Total archived records and total read records are the same count", 24, archivedRecordsCount);
+    assertTrue("Average Archived records per block is greater than 1", archivedRecordsCount / numBlocks > 1);
     // make sure the archived commits are the same as the (originalcommits - commitsleft)
-    List<String> readCommits = readRecords.stream().map(r -> (GenericRecord) r).map(r -> {
+    Set<String> readCommits = readRecords.stream().map(r -> (GenericRecord) r).map(r -> {
       return r.get("commitTime").toString();
-    }).collect(Collectors.toList());
-    Collections.sort(readCommits);
+    }).collect(Collectors.toSet());
 
     assertEquals("Read commits map should match the originalCommits - commitsLoadedFromArchival",
-        originalCommits.stream().map(HoodieInstant::getTimestamp).collect(Collectors.toList()), readCommits);
+        originalCommits.stream().map(HoodieInstant::getTimestamp).collect(Collectors.toSet()), readCommits);
 
     // verify in-flight instants after archive
-    verifyInflightInstants(metaClient, 3);
+    verifyInflightInstants(metaClient, 2);
     reader.close();
   }
 
   @Test
-  public void testArchiveDatasetWithNoArchival() throws IOException {
+  public void testArchiveTableWithNoArchival() throws IOException {
     HoodieWriteConfig cfg = HoodieWriteConfig.newBuilder().withPath(basePath)
         .withSchema(HoodieTestDataGenerator.TRIP_EXAMPLE_SCHEMA).withParallelism(2, 2).forTable("test-trip-table")
         .withCompactionConfig(HoodieCompactionConfig.newBuilder().retainCommits(1).archiveCommitsWith(2, 5).build())
@@ -270,8 +272,8 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     timeline = metaClient.getActiveTimeline().reload().getCommitsTimeline().filterCompletedInstants();
     assertEquals("Should not archive commits when maxCommitsToKeep is 5", 4, timeline.countInstants());
 
-    List<HoodieInstant> instants = HoodieTableMetaClient.scanHoodieInstantsFromFileSystem(metaClient.getFs(),
-        new Path(metaClient.getMetaAuxiliaryPath()), HoodieActiveTimeline.VALID_EXTENSIONS_IN_ACTIVE_TIMELINE);
+    List<HoodieInstant> instants = metaClient.scanHoodieInstantsFromFileSystem(
+        new Path(metaClient.getMetaAuxiliaryPath()), HoodieActiveTimeline.VALID_EXTENSIONS_IN_ACTIVE_TIMELINE, false);
     assertEquals("Should not delete any aux compaction files when maxCommitsToKeep is 5", 8, instants.size());
     assertTrue("Requested Compaction must be present for 100",
         instants.contains(new HoodieInstant(State.REQUESTED, HoodieTimeline.COMPACTION_ACTION, "100")));
@@ -339,7 +341,7 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     assertTrue(result);
     timeline = metaClient.getActiveTimeline().reload().getCommitsTimeline().filterCompletedInstants();
     assertEquals(
-        "Since we have a savepoint at 101, we should never archive any commit after 101 (we only " + "archive 100)", 5,
+        "Since we have a savepoint at 101, we should never archive any commit after 101 (we only archive 100)", 5,
         timeline.countInstants());
     assertTrue("Archived commits should always be safe",
         timeline.containsInstant(new HoodieInstant(false, HoodieTimeline.COMMIT_ACTION, "101")));
@@ -378,7 +380,7 @@ public class TestHoodieCommitArchiveLog extends HoodieClientTestHarness {
     assertFalse("Instants before oldest pending compaction can be removed",
         timeline.containsInstant(new HoodieInstant(false, HoodieTimeline.COMMIT_ACTION, "100")));
     assertEquals("Since we have a pending compaction at 101, we should never archive any commit "
-        + "after 101 (we only " + "archive 100)", 7, timeline.countInstants());
+        + "after 101 (we only archive 100)", 7, timeline.countInstants());
     assertTrue("Requested Compaction must still be present",
         timeline.containsInstant(new HoodieInstant(State.REQUESTED, HoodieTimeline.COMPACTION_ACTION, "101")));
     assertTrue("Instants greater than oldest pending compaction must be present",
