@@ -18,7 +18,29 @@
 
 package org.apache.hudi.common.table.view;
 
+import org.apache.hudi.common.model.CompactionOperation;
+import org.apache.hudi.common.model.FileSlice;
+import org.apache.hudi.common.model.HoodieBaseFile;
+import org.apache.hudi.common.model.HoodieFileGroup;
+import org.apache.hudi.common.model.HoodieFileGroupId;
+import org.apache.hudi.common.model.HoodieLogFile;
+import org.apache.hudi.common.table.HoodieTableMetaClient;
+import org.apache.hudi.common.table.HoodieTimeline;
+import org.apache.hudi.common.table.SyncableFileSystemView;
+import org.apache.hudi.common.table.timeline.HoodieInstant;
+import org.apache.hudi.common.util.CompactionUtils;
+import org.apache.hudi.common.util.FSUtils;
+import org.apache.hudi.common.util.HoodieTimer;
+import org.apache.hudi.common.util.Option;
+import org.apache.hudi.common.util.collection.Pair;
+import org.apache.hudi.exception.HoodieIOException;
+
 import com.google.common.base.Preconditions;
+import org.apache.hadoop.fs.FileStatus;
+import org.apache.hadoop.fs.Path;
+import org.apache.log4j.LogManager;
+import org.apache.log4j.Logger;
+
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -34,37 +56,17 @@ import java.util.concurrent.locks.ReentrantReadWriteLock.WriteLock;
 import java.util.function.Predicate;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
-import org.apache.hadoop.fs.FileStatus;
-import org.apache.hadoop.fs.Path;
-import org.apache.hudi.common.model.CompactionOperation;
-import org.apache.hudi.common.model.FileSlice;
-import org.apache.hudi.common.model.HoodieDataFile;
-import org.apache.hudi.common.model.HoodieFileGroup;
-import org.apache.hudi.common.model.HoodieFileGroupId;
-import org.apache.hudi.common.model.HoodieLogFile;
-import org.apache.hudi.common.table.HoodieTableMetaClient;
-import org.apache.hudi.common.table.HoodieTimeline;
-import org.apache.hudi.common.table.SyncableFileSystemView;
-import org.apache.hudi.common.table.timeline.HoodieInstant;
-import org.apache.hudi.common.util.CompactionUtils;
-import org.apache.hudi.common.util.FSUtils;
-import org.apache.hudi.common.util.HoodieTimer;
-import org.apache.hudi.common.util.Option;
-import org.apache.hudi.common.util.collection.Pair;
-import org.apache.hudi.exception.HoodieIOException;
-import org.apache.log4j.LogManager;
-import org.apache.log4j.Logger;
 
 /**
  * Common thread-safe implementation for multiple TableFileSystemView Implementations. Provides uniform handling of (a)
  * Loading file-system views from underlying file-system (b) Pending compaction operations and changing file-system
- * views based on that (c) Thread-safety in loading and managing file system views for this dataset. (d) resetting
+ * views based on that (c) Thread-safety in loading and managing file system views for this table. (d) resetting
  * file-system views The actual mechanism of fetching file slices from different view storages is delegated to
  * sub-classes.
  */
 public abstract class AbstractTableFileSystemView implements SyncableFileSystemView, Serializable {
 
-  private static Logger log = LogManager.getLogger(AbstractTableFileSystemView.class);
+  private static final Logger LOG = LogManager.getLogger(AbstractTableFileSystemView.class);
 
   protected HoodieTableMetaClient metaClient;
 
@@ -97,7 +99,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Refresh commits timeline
+   * Refresh commits timeline.
    * 
    * @param visibleActiveTimeline Visible Active Timeline
    */
@@ -121,26 +123,26 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       }
     });
     long storePartitionsTs = timer.endTimer();
-    log.info("addFilesToView: NumFiles=" + statuses.length + ", FileGroupsCreationTime=" + fgBuildTimeTakenMs
+    LOG.info("addFilesToView: NumFiles=" + statuses.length + ", FileGroupsCreationTime=" + fgBuildTimeTakenMs
         + ", StoreTimeTaken=" + storePartitionsTs);
     return fileGroups;
   }
 
   /**
-   * Build FileGroups from passed in file-status
+   * Build FileGroups from passed in file-status.
    */
   protected List<HoodieFileGroup> buildFileGroups(FileStatus[] statuses, HoodieTimeline timeline,
       boolean addPendingCompactionFileSlice) {
-    return buildFileGroups(convertFileStatusesToDataFiles(statuses), convertFileStatusesToLogFiles(statuses), timeline,
+    return buildFileGroups(convertFileStatusesToBaseFiles(statuses), convertFileStatusesToLogFiles(statuses), timeline,
         addPendingCompactionFileSlice);
   }
 
-  protected List<HoodieFileGroup> buildFileGroups(Stream<HoodieDataFile> dataFileStream,
+  protected List<HoodieFileGroup> buildFileGroups(Stream<HoodieBaseFile> baseFileStream,
       Stream<HoodieLogFile> logFileStream, HoodieTimeline timeline, boolean addPendingCompactionFileSlice) {
-    Map<Pair<String, String>, List<HoodieDataFile>> dataFiles =
-        dataFileStream.collect(Collectors.groupingBy((dataFile) -> {
-          String partitionPathStr = getPartitionPathFromFilePath(dataFile.getPath());
-          return Pair.of(partitionPathStr, dataFile.getFileId());
+    Map<Pair<String, String>, List<HoodieBaseFile>> baseFiles =
+        baseFileStream.collect(Collectors.groupingBy((baseFile) -> {
+          String partitionPathStr = getPartitionPathFromFilePath(baseFile.getPath());
+          return Pair.of(partitionPathStr, baseFile.getFileId());
         }));
 
     Map<Pair<String, String>, List<HoodieLogFile>> logFiles = logFileStream.collect(Collectors.groupingBy((logFile) -> {
@@ -149,15 +151,15 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       return Pair.of(partitionPathStr, logFile.getFileId());
     }));
 
-    Set<Pair<String, String>> fileIdSet = new HashSet<>(dataFiles.keySet());
+    Set<Pair<String, String>> fileIdSet = new HashSet<>(baseFiles.keySet());
     fileIdSet.addAll(logFiles.keySet());
 
     List<HoodieFileGroup> fileGroups = new ArrayList<>();
     fileIdSet.forEach(pair -> {
       String fileId = pair.getValue();
       HoodieFileGroup group = new HoodieFileGroup(pair.getKey(), fileId, timeline);
-      if (dataFiles.containsKey(pair)) {
-        dataFiles.get(pair).forEach(group::addDataFile);
+      if (baseFiles.containsKey(pair)) {
+        baseFiles.get(pair).forEach(group::addBaseFile);
       }
       if (logFiles.containsKey(pair)) {
         logFiles.get(pair).forEach(group::addLogFile);
@@ -178,8 +180,9 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Clears the partition Map and reset view states
+   * Clears the partition Map and reset view states.
    */
+  @Override
   public final void reset() {
     try {
       writeLock.lock();
@@ -195,12 +198,12 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Allows all view metadata in file system view storage to be reset by subclasses
+   * Allows all view metadata in file system view storage to be reset by subclasses.
    */
   protected abstract void resetViewState();
 
   /**
-   * Allows lazily loading the partitions if needed
+   * Allows lazily loading the partitions if needed.
    *
    * @param partition partition to be loaded if not present
    */
@@ -214,7 +217,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       if (!isPartitionAvailableInStore(partitionPathStr)) {
         // Not loaded yet
         try {
-          log.info("Building file system view for partition (" + partitionPathStr + ")");
+          LOG.info("Building file system view for partition (" + partitionPathStr + ")");
 
           // Create the path if it does not exist already
           Path partitionPath = FSUtils.getPartitionPath(metaClient.getBasePath(), partitionPathStr);
@@ -222,7 +225,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
           long beginLsTs = System.currentTimeMillis();
           FileStatus[] statuses = metaClient.getFs().listStatus(partitionPath);
           long endLsTs = System.currentTimeMillis();
-          log.info("#files found in partition (" + partitionPathStr + ") =" + statuses.length + ", Time taken ="
+          LOG.info("#files found in partition (" + partitionPathStr + ") =" + statuses.length + ", Time taken ="
               + (endLsTs - beginLsTs));
           List<HoodieFileGroup> groups = addFilesToView(statuses);
 
@@ -230,78 +233,78 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
             storePartitionView(partitionPathStr, new ArrayList<>());
           }
         } catch (IOException e) {
-          throw new HoodieIOException("Failed to list data files in partition " + partitionPathStr, e);
+          throw new HoodieIOException("Failed to list base files in partition " + partitionPathStr, e);
         }
       } else {
-        log.debug("View already built for Partition :" + partitionPathStr + ", FOUND is ");
+        LOG.debug("View already built for Partition :" + partitionPathStr + ", FOUND is ");
       }
       long endTs = System.currentTimeMillis();
-      log.info("Time to load partition (" + partitionPathStr + ") =" + (endTs - beginTs));
+      LOG.info("Time to load partition (" + partitionPathStr + ") =" + (endTs - beginTs));
       return true;
     });
   }
 
   /**
-   * Helper to convert file-status to data-files
+   * Helper to convert file-status to base-files.
    *
    * @param statuses List of File-Status
    */
-  private Stream<HoodieDataFile> convertFileStatusesToDataFiles(FileStatus[] statuses) {
+  private Stream<HoodieBaseFile> convertFileStatusesToBaseFiles(FileStatus[] statuses) {
     Predicate<FileStatus> roFilePredicate = fileStatus -> fileStatus.getPath().getName()
-        .contains(metaClient.getTableConfig().getROFileFormat().getFileExtension());
-    return Arrays.stream(statuses).filter(roFilePredicate).map(HoodieDataFile::new);
+        .contains(metaClient.getTableConfig().getBaseFileFormat().getFileExtension());
+    return Arrays.stream(statuses).filter(roFilePredicate).map(HoodieBaseFile::new);
   }
 
   /**
-   * Helper to convert file-status to log-files
+   * Helper to convert file-status to log-files.
    *
    * @param statuses List of FIle-Status
    */
   private Stream<HoodieLogFile> convertFileStatusesToLogFiles(FileStatus[] statuses) {
     Predicate<FileStatus> rtFilePredicate = fileStatus -> fileStatus.getPath().getName()
-        .contains(metaClient.getTableConfig().getRTFileFormat().getFileExtension());
+        .contains(metaClient.getTableConfig().getLogFileFormat().getFileExtension());
     return Arrays.stream(statuses).filter(rtFilePredicate).map(HoodieLogFile::new);
   }
 
   /**
-   * With async compaction, it is possible to see partial/complete data-files due to inflight-compactions, Ignore those
-   * data-files
+   * With async compaction, it is possible to see partial/complete base-files due to inflight-compactions, Ignore those
+   * base-files.
    *
-   * @param dataFile Data File
+   * @param baseFile base File
    */
-  protected boolean isDataFileDueToPendingCompaction(HoodieDataFile dataFile) {
-    final String partitionPath = getPartitionPathFromFilePath(dataFile.getPath());
+  protected boolean isBaseFileDueToPendingCompaction(HoodieBaseFile baseFile) {
+    final String partitionPath = getPartitionPathFromFilePath(baseFile.getPath());
 
     Option<Pair<String, CompactionOperation>> compactionWithInstantTime =
-        getPendingCompactionOperationWithInstant(new HoodieFileGroupId(partitionPath, dataFile.getFileId()));
+        getPendingCompactionOperationWithInstant(new HoodieFileGroupId(partitionPath, baseFile.getFileId()));
     return (compactionWithInstantTime.isPresent()) && (null != compactionWithInstantTime.get().getKey())
-        && dataFile.getCommitTime().equals(compactionWithInstantTime.get().getKey());
+        && baseFile.getCommitTime().equals(compactionWithInstantTime.get().getKey());
   }
 
   /**
    * Returns true if the file-group is under pending-compaction and the file-slice' baseInstant matches compaction
-   * Instant
+   * Instant.
    *
    * @param fileSlice File Slice
    */
   protected boolean isFileSliceAfterPendingCompaction(FileSlice fileSlice) {
     Option<Pair<String, CompactionOperation>> compactionWithInstantTime =
         getPendingCompactionOperationWithInstant(fileSlice.getFileGroupId());
-    log.info("Pending Compaction instant for (" + fileSlice + ") is :" + compactionWithInstantTime);
+    LOG.info("Pending Compaction instant for (" + fileSlice + ") is :" + compactionWithInstantTime);
     return (compactionWithInstantTime.isPresent())
         && fileSlice.getBaseInstantTime().equals(compactionWithInstantTime.get().getKey());
   }
 
   /**
-   * With async compaction, it is possible to see partial/complete data-files due to inflight-compactions, Ignore those
-   * data-files
+   * With async compaction, it is possible to see partial/complete base-files due to inflight-compactions, Ignore those
+   * base-files.
    *
    * @param fileSlice File Slice
    */
-  protected FileSlice filterDataFileAfterPendingCompaction(FileSlice fileSlice) {
+  protected FileSlice filterBaseFileAfterPendingCompaction(FileSlice fileSlice) {
     if (isFileSliceAfterPendingCompaction(fileSlice)) {
-      log.info("File Slice (" + fileSlice + ") is in pending compaction");
-      // Data file is filtered out of the file-slice as the corresponding compaction
+      LOG.info("File Slice (" + fileSlice + ") is in pending compaction");
+      // Base file is filtered out of the file-slice as the corresponding compaction
       // instant not completed yet.
       FileSlice transformed =
           new FileSlice(fileSlice.getPartitionPath(), fileSlice.getBaseInstantTime(), fileSlice.getFileId());
@@ -322,38 +325,38 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   @Override
-  public final Stream<HoodieDataFile> getLatestDataFiles(String partitionStr) {
+  public final Stream<HoodieBaseFile> getLatestBaseFiles(String partitionStr) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
-      return fetchLatestDataFiles(partitionPath);
+      return fetchLatestBaseFiles(partitionPath);
     } finally {
       readLock.unlock();
     }
   }
 
   @Override
-  public final Stream<HoodieDataFile> getLatestDataFiles() {
+  public final Stream<HoodieBaseFile> getLatestBaseFiles() {
     try {
       readLock.lock();
-      return fetchLatestDataFiles();
+      return fetchLatestBaseFiles();
     } finally {
       readLock.unlock();
     }
   }
 
   @Override
-  public final Stream<HoodieDataFile> getLatestDataFilesBeforeOrOn(String partitionStr, String maxCommitTime) {
+  public final Stream<HoodieBaseFile> getLatestBaseFilesBeforeOrOn(String partitionStr, String maxCommitTime) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
       return fetchAllStoredFileGroups(partitionPath)
-          .map(fileGroup -> Option.fromJavaOptional(fileGroup.getAllDataFiles()
-              .filter(dataFile -> HoodieTimeline.compareTimestamps(dataFile.getCommitTime(), maxCommitTime,
+          .map(fileGroup -> Option.fromJavaOptional(fileGroup.getAllBaseFiles()
+              .filter(baseFile -> HoodieTimeline.compareTimestamps(baseFile.getCommitTime(), maxCommitTime,
                   HoodieTimeline.LESSER_OR_EQUAL))
-              .filter(df -> !isDataFileDueToPendingCompaction(df)).findFirst()))
+              .filter(df -> !isBaseFileDueToPendingCompaction(df)).findFirst()))
           .filter(Option::isPresent).map(Option::get);
     } finally {
       readLock.unlock();
@@ -361,42 +364,43 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   @Override
-  public final Option<HoodieDataFile> getDataFileOn(String partitionStr, String instantTime, String fileId) {
+  public final Option<HoodieBaseFile> getBaseFileOn(String partitionStr, String instantTime, String fileId) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
-      return fetchHoodieFileGroup(partitionPath, fileId).map(fileGroup -> fileGroup.getAllDataFiles()
+      return fetchHoodieFileGroup(partitionPath, fileId).map(fileGroup -> fileGroup.getAllBaseFiles()
           .filter(
-              dataFile -> HoodieTimeline.compareTimestamps(dataFile.getCommitTime(), instantTime, HoodieTimeline.EQUAL))
-          .filter(df -> !isDataFileDueToPendingCompaction(df)).findFirst().orElse(null));
+              baseFile -> HoodieTimeline.compareTimestamps(baseFile.getCommitTime(), instantTime, HoodieTimeline.EQUAL))
+          .filter(df -> !isBaseFileDueToPendingCompaction(df)).findFirst().orElse(null));
     } finally {
       readLock.unlock();
     }
   }
 
   /**
-   * Get Latest data file for a partition and file-Id
+   * Get Latest base file for a partition and file-Id.
    */
-  public final Option<HoodieDataFile> getLatestDataFile(String partitionStr, String fileId) {
+  @Override
+  public final Option<HoodieBaseFile> getLatestBaseFile(String partitionStr, String fileId) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
-      return fetchLatestDataFile(partitionPath, fileId);
+      return fetchLatestBaseFile(partitionPath, fileId);
     } finally {
       readLock.unlock();
     }
   }
 
   @Override
-  public final Stream<HoodieDataFile> getLatestDataFilesInRange(List<String> commitsToReturn) {
+  public final Stream<HoodieBaseFile> getLatestBaseFilesInRange(List<String> commitsToReturn) {
     try {
       readLock.lock();
       return fetchAllStoredFileGroups().map(fileGroup -> {
         return Option.fromJavaOptional(
-            fileGroup.getAllDataFiles().filter(dataFile -> commitsToReturn.contains(dataFile.getCommitTime())
-                && !isDataFileDueToPendingCompaction(dataFile)).findFirst());
+            fileGroup.getAllBaseFiles().filter(baseFile -> commitsToReturn.contains(baseFile.getCommitTime())
+                && !isBaseFileDueToPendingCompaction(baseFile)).findFirst());
       }).filter(Option::isPresent).map(Option::get);
     } finally {
       readLock.unlock();
@@ -404,14 +408,14 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   @Override
-  public final Stream<HoodieDataFile> getAllDataFiles(String partitionStr) {
+  public final Stream<HoodieBaseFile> getAllBaseFiles(String partitionStr) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
-      return fetchAllDataFiles(partitionPath)
+      return fetchAllBaseFiles(partitionPath)
           .filter(df -> visibleCommitsAndCompactionTimeline.containsOrBeforeTimelineStarts(df.getCommitTime()))
-          .filter(df -> !isDataFileDueToPendingCompaction(df));
+          .filter(df -> !isBaseFileDueToPendingCompaction(df));
     } finally {
       readLock.unlock();
     }
@@ -423,22 +427,23 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
-      return fetchLatestFileSlices(partitionPath).map(fs -> filterDataFileAfterPendingCompaction(fs));
+      return fetchLatestFileSlices(partitionPath).map(this::filterBaseFileAfterPendingCompaction);
     } finally {
       readLock.unlock();
     }
   }
 
   /**
-   * Get Latest File Slice for a given fileId in a given partition
+   * Get Latest File Slice for a given fileId in a given partition.
    */
+  @Override
   public final Option<FileSlice> getLatestFileSlice(String partitionStr, String fileId) {
     try {
       readLock.lock();
       String partitionPath = formatPartitionKey(partitionStr);
       ensurePartitionLoadedCorrectly(partitionPath);
       Option<FileSlice> fs = fetchLatestFileSlice(partitionPath, fileId);
-      return fs.map(f -> filterDataFileAfterPendingCompaction(f));
+      return fs.map(f -> filterBaseFileAfterPendingCompaction(f));
     } finally {
       readLock.unlock();
     }
@@ -475,7 +480,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       ensurePartitionLoadedCorrectly(partitionPath);
       Stream<FileSlice> fileSliceStream = fetchLatestFileSlicesBeforeOrOn(partitionPath, maxCommitTime);
       if (includeFileSlicesInPendingCompaction) {
-        return fileSliceStream.map(fs -> filterDataFileAfterPendingCompaction(fs));
+        return fileSliceStream.map(fs -> filterBaseFileAfterPendingCompaction(fs));
       } else {
         return fileSliceStream.filter(fs -> !isPendingCompactionScheduledForFileId(fs.getFileGroupId()));
       }
@@ -550,7 +555,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   // Fetch APIs to be implemented by concrete sub-classes
 
   /**
-   * Check if there is an outstanding compaction scheduled for this file
+   * Check if there is an outstanding compaction scheduled for this file.
    *
    * @param fgId File-Group Id
    * @return true if there is a pending compaction, false otherwise
@@ -558,28 +563,28 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   protected abstract boolean isPendingCompactionScheduledForFileId(HoodieFileGroupId fgId);
 
   /**
-   * resets the pending compaction operation and overwrite with the new list
+   * resets the pending compaction operation and overwrite with the new list.
    *
    * @param operations Pending Compaction Operations
    */
   abstract void resetPendingCompactionOperations(Stream<Pair<String, CompactionOperation>> operations);
 
   /**
-   * Add pending compaction operations to store
+   * Add pending compaction operations to store.
    *
    * @param operations Pending compaction operations to be added
    */
   abstract void addPendingCompactionOperations(Stream<Pair<String, CompactionOperation>> operations);
 
   /**
-   * Remove pending compaction operations from store
+   * Remove pending compaction operations from store.
    *
    * @param operations Pending compaction operations to be removed
    */
   abstract void removePendingCompactionOperations(Stream<Pair<String, CompactionOperation>> operations);
 
   /**
-   * Return pending compaction operation for a file-group
+   * Return pending compaction operation for a file-group.
    *
    * @param fileGroupId File-Group Id
    */
@@ -587,19 +592,19 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
       HoodieFileGroupId fileGroupId);
 
   /**
-   * Fetch all pending compaction operations
+   * Fetch all pending compaction operations.
    */
   abstract Stream<Pair<String, CompactionOperation>> fetchPendingCompactionOperations();
 
   /**
-   * Checks if partition is pre-loaded and available in store
+   * Checks if partition is pre-loaded and available in store.
    *
    * @param partitionPath Partition Path
    */
   abstract boolean isPartitionAvailableInStore(String partitionPath);
 
   /**
-   * Add a complete partition view to store
+   * Add a complete partition view to store.
    *
    * @param partitionPath Partition Path
    * @param fileGroups File Groups for the partition path
@@ -607,7 +612,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   abstract void storePartitionView(String partitionPath, List<HoodieFileGroup> fileGroups);
 
   /**
-   * Fetch all file-groups stored for a partition-path
+   * Fetch all file-groups stored for a partition-path.
    *
    * @param partitionPath Partition path for which the file-groups needs to be retrieved.
    * @return file-group stream
@@ -615,19 +620,19 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   abstract Stream<HoodieFileGroup> fetchAllStoredFileGroups(String partitionPath);
 
   /**
-   * Fetch all Stored file-groups across all partitions loaded
+   * Fetch all Stored file-groups across all partitions loaded.
    *
    * @return file-group stream
    */
   abstract Stream<HoodieFileGroup> fetchAllStoredFileGroups();
 
   /**
-   * Check if the view is already closed
+   * Check if the view is already closed.
    */
   abstract boolean isClosed();
 
   /**
-   * Default implementation for fetching latest file-slice in commit range
+   * Default implementation for fetching latest file-slice in commit range.
    *
    * @param commitsToReturn Commits
    */
@@ -637,7 +642,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Default implementation for fetching all file-slices for a partition-path
+   * Default implementation for fetching all file-slices for a partition-path.
    *
    * @param partitionPath Partition path
    * @return file-slice stream
@@ -648,38 +653,37 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Default implementation for fetching latest data-files for the partition-path
+   * Default implementation for fetching latest base-files for the partition-path.
    */
-  Stream<HoodieDataFile> fetchLatestDataFiles(final String partitionPath) {
-    return fetchAllStoredFileGroups(partitionPath).map(this::getLatestDataFile).filter(Option::isPresent)
+  Stream<HoodieBaseFile> fetchLatestBaseFiles(final String partitionPath) {
+    return fetchAllStoredFileGroups(partitionPath).map(this::getLatestBaseFile).filter(Option::isPresent)
         .map(Option::get);
   }
 
-
-  protected Option<HoodieDataFile> getLatestDataFile(HoodieFileGroup fileGroup) {
+  protected Option<HoodieBaseFile> getLatestBaseFile(HoodieFileGroup fileGroup) {
     return Option
-        .fromJavaOptional(fileGroup.getAllDataFiles().filter(df -> !isDataFileDueToPendingCompaction(df)).findFirst());
+        .fromJavaOptional(fileGroup.getAllBaseFiles().filter(df -> !isBaseFileDueToPendingCompaction(df)).findFirst());
   }
 
   /**
-   * Default implementation for fetching latest data-files across all partitions
+   * Default implementation for fetching latest base-files across all partitions.
    */
-  Stream<HoodieDataFile> fetchLatestDataFiles() {
-    return fetchAllStoredFileGroups().map(this::getLatestDataFile).filter(Option::isPresent).map(Option::get);
+  Stream<HoodieBaseFile> fetchLatestBaseFiles() {
+    return fetchAllStoredFileGroups().map(this::getLatestBaseFile).filter(Option::isPresent).map(Option::get);
   }
 
   /**
-   * Default implementation for fetching all data-files for a partition
+   * Default implementation for fetching all base-files for a partition.
    *
    * @param partitionPath partition-path
    */
-  Stream<HoodieDataFile> fetchAllDataFiles(String partitionPath) {
-    return fetchAllStoredFileGroups(partitionPath).map(HoodieFileGroup::getAllDataFiles)
-        .flatMap(dataFileList -> dataFileList);
+  Stream<HoodieBaseFile> fetchAllBaseFiles(String partitionPath) {
+    return fetchAllStoredFileGroups(partitionPath).map(HoodieFileGroup::getAllBaseFiles)
+        .flatMap(baseFileList -> baseFileList);
   }
 
   /**
-   * Default implementation for fetching file-group
+   * Default implementation for fetching file-group.
    */
   Option<HoodieFileGroup> fetchHoodieFileGroup(String partitionPath, String fileId) {
     return Option.fromJavaOptional(fetchAllStoredFileGroups(partitionPath)
@@ -687,7 +691,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Default implementation for fetching latest file-slices for a partition path
+   * Default implementation for fetching latest file-slices for a partition path.
    */
   Stream<FileSlice> fetchLatestFileSlices(String partitionPath) {
     return fetchAllStoredFileGroups(partitionPath).map(HoodieFileGroup::getLatestFileSlice).filter(Option::isPresent)
@@ -695,7 +699,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Default implementation for fetching latest file-slices for a partition path as of instant
+   * Default implementation for fetching latest file-slices for a partition path as of instant.
    *
    * @param partitionPath Partition Path
    * @param maxCommitTime Instant Time
@@ -715,8 +719,8 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   private static FileSlice mergeCompactionPendingFileSlices(FileSlice lastSlice, FileSlice penultimateSlice) {
     FileSlice merged = new FileSlice(penultimateSlice.getPartitionPath(), penultimateSlice.getBaseInstantTime(),
         penultimateSlice.getFileId());
-    if (penultimateSlice.getDataFile().isPresent()) {
-      merged.setDataFile(penultimateSlice.getDataFile().get());
+    if (penultimateSlice.getBaseFile().isPresent()) {
+      merged.setBaseFile(penultimateSlice.getBaseFile().get());
     }
     // Add Log files from penultimate and last slices
     penultimateSlice.getLogFiles().forEach(merged::addLogFile);
@@ -726,7 +730,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
 
   /**
    * If the file-slice is because of pending compaction instant, this method merges the file-slice with the one before
-   * the compaction instant time
+   * the compaction instant time.
    *
    * @param fileGroup File Group for which the file slice belongs to
    * @param fileSlice File Slice which needs to be merged
@@ -748,19 +752,19 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Default implementation for fetching latest data-file
+   * Default implementation for fetching latest base-file.
    * 
    * @param partitionPath Partition path
    * @param fileId File Id
-   * @return Data File if present
+   * @return base File if present
    */
-  protected Option<HoodieDataFile> fetchLatestDataFile(String partitionPath, String fileId) {
-    return Option
-        .fromJavaOptional(fetchLatestDataFiles(partitionPath).filter(fs -> fs.getFileId().equals(fileId)).findFirst());
+  protected Option<HoodieBaseFile> fetchLatestBaseFile(String partitionPath, String fileId) {
+    return Option.fromJavaOptional(fetchLatestBaseFiles(partitionPath)
+        .filter(fs -> fs.getFileId().equals(fileId)).findFirst());
   }
 
   /**
-   * Default implementation for fetching file-slice
+   * Default implementation for fetching file-slice.
    * 
    * @param partitionPath Partition path
    * @param fileId File Id
@@ -809,7 +813,7 @@ public abstract class AbstractTableFileSystemView implements SyncableFileSystemV
   }
 
   /**
-   * Return Only Commits and Compaction timeline for building file-groups
+   * Return Only Commits and Compaction timeline for building file-groups.
    * 
    * @return
    */
