@@ -18,33 +18,9 @@
 
 package org.apache.hudi.utilities.deltastreamer;
 
-import com.beust.jcommander.IStringConverter;
-import com.beust.jcommander.JCommander;
-import com.beust.jcommander.Parameter;
-import com.beust.jcommander.ParameterException;
-import com.google.common.base.Preconditions;
-import java.io.IOException;
-import java.io.Serializable;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.BlockingQueue;
-import java.util.concurrent.CompletableFuture;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.locks.Condition;
-import java.util.concurrent.locks.ReentrantLock;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
-import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.fs.FileSystem;
-import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hudi.HoodieWriteClient;
-import org.apache.hudi.OverwriteWithLatestAvroPayload;
 import org.apache.hudi.common.model.HoodieTableType;
+import org.apache.hudi.common.model.OverwriteWithLatestAvroPayload;
 import org.apache.hudi.common.table.HoodieTableMetaClient;
 import org.apache.hudi.common.table.HoodieTimeline;
 import org.apache.hudi.common.table.timeline.HoodieInstant;
@@ -60,24 +36,49 @@ import org.apache.hudi.utilities.HiveIncrementalPuller;
 import org.apache.hudi.utilities.UtilHelpers;
 import org.apache.hudi.utilities.schema.SchemaProvider;
 import org.apache.hudi.utilities.sources.JsonDFSSource;
+
+import com.beust.jcommander.IStringConverter;
+import com.beust.jcommander.JCommander;
+import com.beust.jcommander.Parameter;
+import com.beust.jcommander.ParameterException;
+import com.google.common.base.Preconditions;
+import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.fs.FileSystem;
+import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.log4j.LogManager;
 import org.apache.log4j.Logger;
 import org.apache.spark.api.java.JavaSparkContext;
 import org.apache.spark.sql.SparkSession;
 
+import java.io.IOException;
+import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
+import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.locks.Condition;
+import java.util.concurrent.locks.ReentrantLock;
+import java.util.stream.Collectors;
+import java.util.stream.IntStream;
 
 /**
  * An Utility which can incrementally take the output from {@link HiveIncrementalPuller} and apply it to the target
- * dataset. Does not maintain any state, queries at runtime to see how far behind the target dataset is from the source
- * dataset. This can be overriden to force sync from a timestamp.
+ * table. Does not maintain any state, queries at runtime to see how far behind the target table is from the source
+ * table. This can be overriden to force sync from a timestamp.
  *
  * In continuous mode, DeltaStreamer runs in loop-mode going through the below operations (a) pull-from-source (b)
  * write-to-sink (c) Schedule Compactions if needed (d) Conditionally Sync to Hive each cycle. For MOR table with
- * continuous mode enabled, a seperate compactor thread is allocated to execute compactions
+ * continuous mode enabled, a separate compactor thread is allocated to execute compactions
  */
 public class HoodieDeltaStreamer implements Serializable {
 
-  private static volatile Logger log = LogManager.getLogger(HoodieDeltaStreamer.class);
+  private static final Logger LOG = LogManager.getLogger(HoodieDeltaStreamer.class);
 
   public static String CHECKPOINT_KEY = "deltastreamer.checkpoint.key";
 
@@ -106,7 +107,7 @@ public class HoodieDeltaStreamer implements Serializable {
   }
 
   /**
-   * Main method to start syncing
+   * Main method to start syncing.
    * 
    * @throws Exception
    */
@@ -114,17 +115,23 @@ public class HoodieDeltaStreamer implements Serializable {
     if (cfg.continuousMode) {
       deltaSyncService.start(this::onDeltaSyncShutdown);
       deltaSyncService.waitForShutdown();
-      log.info("Delta Sync shutting down");
+      LOG.info("Delta Sync shutting down");
     } else {
-      log.info("Delta Streamer running only single round");
-      deltaSyncService.getDeltaSync().syncOnce();
-      deltaSyncService.close();
-      log.info("Shut down deltastreamer");
+      LOG.info("Delta Streamer running only single round");
+      try {
+        deltaSyncService.getDeltaSync().syncOnce();
+      } catch (Exception ex) {
+        LOG.error("Got error running delta sync once. Shutting down", ex);
+        throw ex;
+      } finally {
+        deltaSyncService.close();
+        LOG.info("Shut down deltastreamer");
+      }
     }
   }
 
   private boolean onDeltaSyncShutdown(boolean error) {
-    log.info("DeltaSync shutdown. Closing write client. Error?" + error);
+    LOG.info("DeltaSync shutdown. Closing write client. Error?" + error);
     deltaSyncService.close();
     return true;
   }
@@ -144,18 +151,16 @@ public class HoodieDeltaStreamer implements Serializable {
   public static class Config implements Serializable {
 
     @Parameter(names = {"--target-base-path"},
-        description = "base path for the target hoodie dataset. "
-            + "(Will be created if did not exist first time around. If exists, expected to be a hoodie dataset)",
+        description = "base path for the target hoodie table. "
+            + "(Will be created if did not exist first time around. If exists, expected to be a hoodie table)",
         required = true)
     public String targetBasePath;
 
-    // TODO: How to obtain hive configs to register?
     @Parameter(names = {"--target-table"}, description = "name of the target table in Hive", required = true)
     public String targetTableName;
 
-    @Parameter(names = {"--storage-type"}, description = "Type of Storage. " + "COPY_ON_WRITE (or) MERGE_ON_READ",
-        required = true)
-    public String storageType;
+    @Parameter(names = {"--table-type"}, description = "Type of table. COPY_ON_WRITE (or) MERGE_ON_READ", required = true)
+    public String tableType;
 
     @Parameter(names = {"--props"}, description = "path to properties file on localfs or dfs, with configurations for "
         + "hoodie client, schema provider, key generator and data source. For hoodie client props, sane defaults are "
@@ -192,7 +197,7 @@ public class HoodieDeltaStreamer implements Serializable {
 
     @Parameter(names = {"--transformer-class"},
         description = "subclass of org.apache.hudi.utilities.transform.Transformer"
-            + ". Allows transforming raw source dataset to a target dataset (conforming to target schema) before "
+            + ". Allows transforming raw source Dataset to a target Dataset (conforming to target schema) before "
             + "writing. Default : Not set. E:g - org.apache.hudi.utilities.transform.SqlQueryBasedTransformer (which "
             + "allows a SQL query templated to be passed as a transformation function)")
     public String transformerClassName = null;
@@ -206,7 +211,7 @@ public class HoodieDeltaStreamer implements Serializable {
     public Operation operation = Operation.UPSERT;
 
     @Parameter(names = {"--filter-dupes"},
-        description = "Should duplicate records from source be dropped/filtered out" + "before insert/bulk-insert")
+        description = "Should duplicate records from source be dropped/filtered out before insert/bulk-insert")
     public Boolean filterDupes = false;
 
     @Parameter(names = {"--enable-hive-sync"}, description = "Enable syncing to hive")
@@ -222,7 +227,7 @@ public class HoodieDeltaStreamer implements Serializable {
     public Boolean continuousMode = false;
 
     @Parameter(names = {"--min-sync-interval-seconds"},
-        description = "the min sync interval of each sync in " + "continuous mode")
+        description = "the min sync interval of each sync in continuous mode")
     public Integer minSyncIntervalSeconds = 0;
 
     @Parameter(names = {"--spark-master"}, description = "spark master to use.")
@@ -252,7 +257,7 @@ public class HoodieDeltaStreamer implements Serializable {
      * Compaction is enabled for MoR table by default. This flag disables it
      */
     @Parameter(names = {"--disable-compaction"},
-        description = "Compaction is enabled for MoR table by default." + "This flag disables it ")
+        description = "Compaction is enabled for MoR table by default. This flag disables it ")
     public Boolean forceDisableCompaction = false;
 
     /**
@@ -261,25 +266,23 @@ public class HoodieDeltaStreamer implements Serializable {
     @Parameter(names = {"--checkpoint"}, description = "Resume Delta Streamer from this checkpoint.")
     public String checkpoint = null;
 
-
     @Parameter(names = {"--help", "-h"}, help = true)
     public Boolean help = false;
 
-
     public boolean isAsyncCompactionEnabled() {
       return continuousMode && !forceDisableCompaction
-          && HoodieTableType.MERGE_ON_READ.equals(HoodieTableType.valueOf(storageType));
+          && HoodieTableType.MERGE_ON_READ.equals(HoodieTableType.valueOf(tableType));
     }
 
     public boolean isInlineCompactionEnabled() {
       return !continuousMode && !forceDisableCompaction
-          && HoodieTableType.MERGE_ON_READ.equals(HoodieTableType.valueOf(storageType));
+          && HoodieTableType.MERGE_ON_READ.equals(HoodieTableType.valueOf(tableType));
     }
   }
 
   public static void main(String[] args) throws Exception {
     final Config cfg = new Config();
-    JCommander cmd = new JCommander(cfg, args);
+    JCommander cmd = new JCommander(cfg, null, args);
     if (cfg.help || args.length == 0) {
       cmd.usage();
       System.exit(1);
@@ -301,7 +304,7 @@ public class HoodieDeltaStreamer implements Serializable {
   public static class DeltaSyncService extends AbstractDeltaStreamerService {
 
     /**
-     * Delta Sync Config
+     * Delta Sync Config.
      */
     private final HoodieDeltaStreamer.Config cfg;
 
@@ -311,12 +314,12 @@ public class HoodieDeltaStreamer implements Serializable {
     private transient SchemaProvider schemaProvider;
 
     /**
-     * Spark Session
+     * Spark Session.
      */
     private transient SparkSession sparkSession;
 
     /**
-     * Spark context
+     * Spark context.
      */
     private transient JavaSparkContext jssc;
 
@@ -326,17 +329,17 @@ public class HoodieDeltaStreamer implements Serializable {
     TypedProperties props;
 
     /**
-     * Async Compactor Service
+     * Async Compactor Service.
      */
     private AsyncCompactService asyncCompactService;
 
     /**
-     * Table Type
+     * Table Type.
      */
     private final HoodieTableType tableType;
 
     /**
-     * Delta Sync
+     * Delta Sync.
      */
     private transient DeltaSync deltaSync;
 
@@ -351,14 +354,14 @@ public class HoodieDeltaStreamer implements Serializable {
             new HoodieTableMetaClient(new Configuration(fs.getConf()), cfg.targetBasePath, false);
         tableType = meta.getTableType();
         // This will guarantee there is no surprise with table type
-        Preconditions.checkArgument(tableType.equals(HoodieTableType.valueOf(cfg.storageType)),
-            "Hoodie table is of type " + tableType + " but passed in CLI argument is " + cfg.storageType);
+        Preconditions.checkArgument(tableType.equals(HoodieTableType.valueOf(cfg.tableType)),
+            "Hoodie table is of type " + tableType + " but passed in CLI argument is " + cfg.tableType);
       } else {
-        tableType = HoodieTableType.valueOf(cfg.storageType);
+        tableType = HoodieTableType.valueOf(cfg.tableType);
       }
 
       this.props = UtilHelpers.readConfig(fs, new Path(cfg.propsFilePath), cfg.configs).getConfig();
-      log.info("Creating delta streamer with configs : " + props.toString());
+      LOG.info("Creating delta streamer with configs : " + props.toString());
       this.schemaProvider = UtilHelpers.createSchemaProvider(cfg.schemaProviderClassName, props, jssc);
 
       if (cfg.filterDupes) {
@@ -380,7 +383,7 @@ public class HoodieDeltaStreamer implements Serializable {
         boolean error = false;
         if (cfg.isAsyncCompactionEnabled()) {
           // set Scheduler Pool.
-          log.info("Setting Spark Pool name for delta-sync to " + SchedulerConfGenerator.DELTASYNC_POOL_NAME);
+          LOG.info("Setting Spark Pool name for delta-sync to " + SchedulerConfGenerator.DELTASYNC_POOL_NAME);
           jssc.setLocalProperty("spark.scheduler.pool", SchedulerConfGenerator.DELTASYNC_POOL_NAME);
         }
         try {
@@ -389,19 +392,19 @@ public class HoodieDeltaStreamer implements Serializable {
               long start = System.currentTimeMillis();
               Option<String> scheduledCompactionInstant = deltaSync.syncOnce();
               if (scheduledCompactionInstant.isPresent()) {
-                log.info("Enqueuing new pending compaction instant (" + scheduledCompactionInstant + ")");
+                LOG.info("Enqueuing new pending compaction instant (" + scheduledCompactionInstant + ")");
                 asyncCompactService.enqueuePendingCompaction(new HoodieInstant(State.REQUESTED,
                     HoodieTimeline.COMPACTION_ACTION, scheduledCompactionInstant.get()));
                 asyncCompactService.waitTillPendingCompactionsReducesTo(cfg.maxPendingCompactions);
               }
               long toSleepMs = cfg.minSyncIntervalSeconds * 1000 - (System.currentTimeMillis() - start);
               if (toSleepMs > 0) {
-                log.info("Last sync ran less than min sync interval: " + cfg.minSyncIntervalSeconds + " s, sleep: "
+                LOG.info("Last sync ran less than min sync interval: " + cfg.minSyncIntervalSeconds + " s, sleep: "
                     + toSleepMs + " ms.");
                 Thread.sleep(toSleepMs);
               }
             } catch (Exception e) {
-              log.error("Shutting down delta-sync due to exception", e);
+              LOG.error("Shutting down delta-sync due to exception", e);
               error = true;
               throw new HoodieException(e.getMessage(), e);
             }
@@ -414,18 +417,18 @@ public class HoodieDeltaStreamer implements Serializable {
     }
 
     /**
-     * Shutdown compactor as DeltaSync is shutdown
+     * Shutdown compactor as DeltaSync is shutdown.
      */
     private void shutdownCompactor(boolean error) {
-      log.info("Delta Sync shutdown. Error ?" + error);
+      LOG.info("Delta Sync shutdown. Error ?" + error);
       if (asyncCompactService != null) {
-        log.warn("Gracefully shutting down compactor");
+        LOG.warn("Gracefully shutting down compactor");
         asyncCompactService.shutdown(false);
       }
     }
 
     /**
-     * Callback to initialize write client and start compaction service if required
+     * Callback to initialize write client and start compaction service if required.
      * 
      * @param writeClient HoodieWriteClient
      * @return
@@ -453,7 +456,7 @@ public class HoodieDeltaStreamer implements Serializable {
     }
 
     /**
-     * Close all resources
+     * Close all resources.
      */
     public void close() {
       if (null != deltaSync) {
@@ -497,19 +500,18 @@ public class HoodieDeltaStreamer implements Serializable {
     public AsyncCompactService(JavaSparkContext jssc, HoodieWriteClient client) {
       this.jssc = jssc;
       this.compactor = new Compactor(client, jssc);
-      // TODO: HUDI-157 : Only allow 1 compactor to run in parallel till Incremental View on MOR is fully implemented.
       this.maxConcurrentCompaction = 1;
     }
 
     /**
-     * Enqueues new Pending compaction
+     * Enqueues new Pending compaction.
      */
     public void enqueuePendingCompaction(HoodieInstant instant) {
       pendingCompactions.add(instant);
     }
 
     /**
-     * Wait till outstanding pending compactions reduces to the passed in value
+     * Wait till outstanding pending compactions reduces to the passed in value.
      * 
      * @param numPendingCompactions Maximum pending compactions allowed
      * @throws InterruptedException
@@ -526,13 +528,13 @@ public class HoodieDeltaStreamer implements Serializable {
     }
 
     /**
-     * Fetch Next pending compaction if available
+     * Fetch Next pending compaction if available.
      * 
      * @return
      * @throws InterruptedException
      */
     private HoodieInstant fetchNextCompactionInstant() throws InterruptedException {
-      log.info("Compactor waiting for next instant for compaction upto 60 seconds");
+      LOG.info("Compactor waiting for next instant for compaction upto 60 seconds");
       HoodieInstant instant = pendingCompactions.poll(60, TimeUnit.SECONDS);
       if (instant != null) {
         try {
@@ -547,15 +549,16 @@ public class HoodieDeltaStreamer implements Serializable {
     }
 
     /**
-     * Start Compaction Service
+     * Start Compaction Service.
      */
+    @Override
     protected Pair<CompletableFuture, ExecutorService> startService() {
       ExecutorService executor = Executors.newFixedThreadPool(maxConcurrentCompaction);
       List<CompletableFuture<Boolean>> compactionFutures =
           IntStream.range(0, maxConcurrentCompaction).mapToObj(i -> CompletableFuture.supplyAsync(() -> {
             try {
               // Set Compactor Pool Name for allowing users to prioritize compaction
-              log.info("Setting Spark Pool name for compaction to " + SchedulerConfGenerator.COMPACT_POOL_NAME);
+              LOG.info("Setting Spark Pool name for compaction to " + SchedulerConfGenerator.COMPACT_POOL_NAME);
               jssc.setLocalProperty("spark.scheduler.pool", SchedulerConfGenerator.COMPACT_POOL_NAME);
 
               while (!isShutdownRequested()) {
@@ -564,11 +567,11 @@ public class HoodieDeltaStreamer implements Serializable {
                   compactor.compact(instant);
                 }
               }
-              log.info("Compactor shutting down properly!!");
+              LOG.info("Compactor shutting down properly!!");
             } catch (InterruptedException ie) {
-              log.warn("Compactor executor thread got interrupted exception. Stopping", ie);
+              LOG.warn("Compactor executor thread got interrupted exception. Stopping", ie);
             } catch (IOException e) {
-              log.error("Compactor executor failed", e);
+              LOG.error("Compactor executor failed", e);
               throw new HoodieIOException(e.getMessage(), e);
             }
             return true;
